#
# spec file for package libaccounts-glib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define typelib typelib-1_0-Accounts-1_0
%define sover   0
Name:           libaccounts-glib
Version:        1.27
Release:        1.2
Summary:        Account management library for GLib Applications
License:        LGPL-2.1-only
URL:            https://gitlab.com/accounts-sso/libaccounts-glib
Source:         https://gitlab.com/accounts-sso/libaccounts-glib/-/archive/VERSION_%{version}/libaccounts-glib-VERSION_%{version}.tar.bz2
Source1:        baselibs.conf
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  pkgconfig(check) >= 0.9.4
BuildRequires:  pkgconfig(gio-2.0) >= 2.36
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.26
BuildRequires:  pkgconfig(gobject-2.0) >= 2.35.1
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pygobject-3.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sqlite3) >= 3.7.0
BuildRequires:  pkgconfig(vapigen)

%description
This package contains the shared libraries for use by applications.

%package -n libaccounts-glib%{sover}
Summary:        Account management library for GLib Applications

%description -n libaccounts-glib%{sover}
This package contains the shared libraries for use by applications.

%package -n %{typelib}
Summary:        Account management library for GLib Applications -- Introspection Bindings

%description -n %{typelib}
This package contains the GObject Introspection bindings for the
accounts-glib library.

%package devel
Summary:        Development files for libaccounts-glib
Requires:       libaccounts-glib%{sover} = %{version}
Requires:       %{typelib} = %{version}

%description devel
This package contains the development files for the accounts-glib
library.

%package docs
Summary:        Documentation for libaccounts-glib
BuildArch:      noarch

%description docs
This package contains the documentation for the accounts-glib
library.

%package tools
Summary:        Tools for libaccounts-glib
Requires:       libaccounts-glib%{sover} = %{version}

%description tools
This package contains the tools for the accounts-glib library.

%prep
%autosetup -p1 -n libaccounts-glib-VERSION_%{version}

%build
%meson

%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libaccounts-glib%{sover}

%files -n libaccounts-glib%{sover}
%doc NEWS
%license COPYING
%{_libdir}/libaccounts-glib.so.%{sover}*
%{_libdir}/libaccounts-glib.so.1.27

%files -n %{typelib}
%{_libdir}/girepository-1.0/Accounts-1.0.typelib

%files devel
%{_includedir}/libaccounts-glib/
%{_datadir}/gettext/
%{_libdir}/libaccounts-glib.so
%{_libdir}/pkgconfig/libaccounts-glib.pc
%{_datadir}/gir-1.0/Accounts-1.0.gir
%dir %{_datadir}/vala/
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/libaccounts-glib.*

%files docs
%doc %{_datadir}/gtk-doc/html/libaccounts-glib/

%files tools
%{_bindir}/ag-backup
%{_bindir}/ag-tool
%dir %{_datadir}/dbus-1/
%dir %{_datadir}/dbus-1/interfaces/
%{_datadir}/dbus-1/interfaces/com.google.code.AccountsSSO.Accounts.Manager.xml
%dir %{_datadir}/xml/accounts/
%dir %{_datadir}/xml/accounts/schema/
%dir %{_datadir}/xml/accounts/schema/dtd/
%{_datadir}/xml/accounts/schema/dtd/accounts-*.dtd

%changelog
* Mon Feb 24 2025 Christophe Marin <christophe@krop.fr>
- Update to 1.27
  * Do not install python gobject introspection files by default.
    If they are needed, build with `-Dinstall-py-overrides=true`.
  * Lib: do not attempt to terminate the GTask twice
  * Fix memory leak on provider tags
  * Do not emit misleading enabled signals on account services
  * Fix incorrect cleanup in ag_account_finalize
- Drop patches, merged upstream:
  * 0001-ag-account-fix-incorrect-cleanup-in-ag_account_final.patch
  * 0002-Build-Don-t-install-Python-overrides-by-default.patch
  * 0003-Lib-do-not-attempt-to-terminate-the-GTask-twice.patch
  * 0004-ag-provider-fix-memory-leak-on-provider-tags.patch
  * 0006-ag-account-do-not-emit-misleading-enabled-signals-on.patch
* Fri Mar  8 2024 Christophe Marin <christophe@krop.fr>
- Add upstream changes:
  * 0001-ag-account-fix-incorrect-cleanup-in-ag_account_final.patch
  * 0002-Build-Don-t-install-Python-overrides-by-default.patch
  * 0003-Lib-do-not-attempt-to-terminate-the-GTask-twice.patch
  * 0004-ag-provider-fix-memory-leak-on-provider-tags.patch
  * 0006-ag-account-do-not-emit-misleading-enabled-signals-on.patch
- Spec cleanup
* Thu Sep 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.26:
  * meson: add /usr/include to pkgconfig include path
  * Avoid assert failure on ag_provider_get_tags
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed baselibs.conf, so version changed
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.25:
  * Add support for provider tags
  * Reference counting is implemented atomically
  * Add option to specify path to pygobject override directory
- Use SourceUrls
* Fri Oct 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24:
  * ag-tool: fix typos.
  * Remove Nokia backup conf files.
  * Now using the meson build system.
  * Bump soname.
- Switch to source service checkout, use explicit released tag.
- Add meson BuildRequires and macros following upstreams port.
- Add pkgconfig(vapigen) BuildRequires: New dependency.
- Drop python-libaccounts subpackage, no longer built.
- Drop autoconf, automake, libtool and pkgconfig(python2)
  BuildRequires: No longer needed.
- Drop _version define, not needed as we are now using source
  service.
- Modernize spec, drop no longer needed tweaks and workarounds.
* Fri Nov  3 2017 buschmann23@opensuse.org
- spec file
  * fix source url
* Thu Nov  2 2017 buschmann23@opensuse.org
- Update to 1.23
  * Add a couple of methods related to .application files:
    ag_manager_list_services_by_application() and
    ag_application_supports_service().
- Update to 1.22
  * Lib: migrate to GTask
  * Build: add support for lcov 1.12
* Wed Feb 24 2016 tittiatcoke@gmail.com
- Update to 1.21
  * Support desktop-specific overrides for service and providers
    files: desktops can define service and providers files in
    /usr/share/accounts/{providers,services}/$XDG_CURRENT_DESKTOP
    and these would override any files having the same name in the
    parent (default) directory.
  * Fixes
- Drop upstream libaccounts-glib-ignore-deprecated-declarations.patch
  no longer required
* Fri Dec 18 2015 fcrozat@suse.com
- Add libaccounts-glib-ignore-deprecated-declarations.patch: fix
  build with latest glib2.
* Mon Oct 19 2015 sor.alexei@meowr.ru
- Update to 1.18:
  * Python: Fix Accounts.Manager() constructor, which got broken
    when version 1.17 was released.
- Fix license.
- Add baselibs.conf.
* Thu Oct 30 2014 hrvoje.senjan@gmail.com
- Update to version 1.17
  * Allow instantiation of AgManager with no D-Bus
  * Tests: increase timeout in test_store_locked_cancel
  * AgManager: expose DB timeout parameters as properties
  * Fix build with -Werror
* Tue Feb 18 2014 tittiatcoke@gmail.com
- Initial package based on version 1.16
